#
# spec file for package perses-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name percli

Name:           perses-cli
Version:        0.51.1
Release:        1.1
Summary:        CLI for the Perses observability visualisation project
License:        Apache-2.0
URL:            https://github.com/perses/perses
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.24
Provides:       percli = %{version}

%description
Perses, a Cloud Native Computing Foundation sandbox project, is a dashboard
tool to visualize observability data from Prometheus/Thanos/Jaeger.

This package contains the CLI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/prometheus/common/version.Version=%{version} \
   -X github.com/prometheus/common/version.Commit=${COMMIT_HASH} \
   -X github.com/prometheus/common/version.Branch=main \
   -X github.com/prometheus/common/version.BuildDate=${BUILD_DATE}" \
   -o bin/%{executable_name} ./cmd/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Wed Jun 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.51.1:
  * [BUGFIX]: Move namespace to correct location for Dashboard CR
    export (#3036)
  * [BUGFIX] Fixing fetch + JWT token expired + replacing
    datasource LRU cache by Tanstack query (#3031)
  * [IGNORE] Bump table plugin to v0.7.1 (#3026)
  * [BUGFIX] Plugin: Fix internal error returned when the plugin
    list is empty (#3022)
  * [BUGFIX] fix issue when configuring datasource with direct
    access (#3016)
  * [BUGFIX] remove wrong array length constraint in transform
    schema (#3012)
  * [BUGFIX] echart: fixing barchart import (#3011)
  * [BUGFIX] fix the redundant consumption of the response object
    when the json and text functions are called (#3009)
* Sat Jun  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.51.0:
  This release is one of the biggest releases we ever made.
  On top of many features and improvements, we are introducing a
  new plugin architecture that allows you to develop external
  plugins and load them in Perses.
  As part of this change we are introducing a new repository
  perses/plugins containing all default plugins supported by
  Perses.
  We have also improved the documentation, highlighting features
  that were implemented some time ago already but not well
  advertised (like datasource discovery and ephemeral dashboards)
  Details and explanations can be found in our blog post:
  https://perses.dev/blog/2025/06/06/release-v0510/
  CLI-related changes
  * [ENHANCEMENT] CLI: improve the "no args are supported" feedback
    for several commands (#2974)
  * [FEATURE] add percli plugin generate command and plugin
    documentation (#2918)
  * [FEATURE] CLI: list the plugins (#2889)
  * [BREAKINGCHANGE] CLI/PLUGIN: implement start command and deep
    review of how to load a dev plugin (#2831)
  * [ENHANCEMENT] CLI/DAC: ignore a list of pre-defined folder when
    building dashboard (#2800)
  * [ENHANCEMENT] CLI/PLUGIN: build includes the version in the
    archive name (#2804)
  * [ENHANCEMENT] CLI/plugin: Improve the way to vendor cue
    dependencies and rely on cue default caching (#2795)
  * [BREAKINGCHANGE] `percli dac setup`: rely on CUE's new modules
    for deps installation (#2724)
  * [BUGFIX] CLI: plugin build should consider all subfolder when
    getting the cue dependencies (#2748)
  * [ENHANCEMENT] rework `percli plugin build` to vendor CUE
    dependencies (#2695)
  * [ignore] add tests for CLI command plugin lint and build
    (#2700)
  * [BUGFIX] CLI/plugin: Improve error returned when files are
    missing in a plugin and fix loading default config file (#2690)
  * [ENHANCEMENT] `percli dac preview`: add current dashboard URL
    to the output when applicable (#2505)
  * [BUGFIX] Login from percli (method not allowed) (#2577)
  * BUGFIX: `percli dac setup`: fix useless requirement of go CLI
    when using CUE (#2544)
  * [ENHANCEMENT] : percli plugin lint: improve the way to find the
    schema files (#2526)
  * [DOC] User Guides and CLI section of the docs updated.  (#2532)
  * [ENHANCEMENT] `percli dac diff`: add output + avoid early
    return when processing a directory (#2500)
  Dependencies
  * Bump github.com/prometheus/common from 0.63.0 to 0.64.0 (#2934)
  * Bump github.com/labstack/echo/v4 from 4.13.3 to 4.13.4 (#2944)
  * Bump github.com/perses/plugins/table from 0.6.0 to 0.6.1 in
    /go-sdk/test (#2963)
  * upgrade vulnerable dependencies (#2970)
  * Bump cuelang.org/go from 0.12.1 to 0.13.0 (#2946)
  * Bump github.com/brunoga/deep from 1.2.4 to 1.2.5 (#2945)
  * Bump github.com/perses/plugins/timeserieschart (#2961)
  * Bump github.com/olekukonko/tablewriter from 1.0.6 to 1.0.7
    (#2962)
  * Bump github.com/perses/plugins/timeserieschart in /go-sdk/test
    (#2964)
  * Bump github.com/perses/plugins/staticlistvariable in
    /go-sdk/test (#2965)
  * Bump the k8s-io group across 1 directory with 3 updates (#2931)
  * Bump github.com/olekukonko/tablewriter from 1.0.3 to 1.0.6
    (#2933)
  * Bump github.com/mholt/archives from 0.1.1 to 0.1.2 (#2932)
  * Bump github.com/olekukonko/tablewriter from 0.0.5 to 1.0.3
    (#2912)
  * Bump github.com/perses/plugins/staticlistvariable in
    /go-sdk/test (#2913)
  * Bump github.com/perses/plugins/timeserieschart in /go-sdk/test
    (#2895)
  * Bump github.com/perses/plugins/timeserieschart (#2897)
  * Bump github.com/perses/plugins/table from 0.5.0 to 0.6.0 in
    /go-sdk/test (#2896)
  * Bump golang.org/x/oauth2 from 0.28.0 to 0.30.0 (#2894)
  * Bump golang.org/x/crypto from 0.36.0 to 0.38.0 (#2851)
  * [ignore] bump go deps (#2900)
  * Bump golangci/golangci-lint-action from 6.5.1 to 8.0.0 (#2828)
  * Bump github.com/google/cel-go from 0.24.1 to 0.25.0 (#2883)
  * Bump github.com/prometheus/client_model from 0.6.1 to 0.6.2
    (#2870)
  * Bump github.com/mholt/archives from 0.1.0 to 0.1.1 (#2854)
  * Bump cuelang.org/go from 0.12.0 to 0.12.1 (#2853)
  * Bump github.com/go-sql-driver/mysql from 1.9.1 to 1.9.2 (#2849)
  * Bump github.com/prometheus/promu from 0.17.0 to 0.18.0 (#2848)
  * [ignore] update go deps (#2836)
  * Bump github.com/perses/plugins/table in /go-sdk/test (#2822)
  * Bump github.com/perses/plugins/timeserieschart in /go-sdk/test
    (#2824)
  * Bump github.com/go-sql-driver/mysql from 1.9.0 to 1.9.1 (#2819)
  * Bump github.com/huandu/go-sqlbuilder from 1.34.0 to 1.35.0
    (#2820)
  * Bump github.com/perses/plugins/timeserieschart (#2826)
  * [ignore] bump go deps (#2798)
  * Bump the k8s-io group across 1 directory with 3 updates (#2782)
  * Bump github.com/perses/plugins/prometheus in /go-sdk/test
    (#2742)
  * Bump github.com/perses/plugins/prometheus (#2743)
  * [IGNORE] Update date-fns and date-fns-tz (#2755)
  * Bump golangci/golangci-lint-action from 6.5.0 to 6.5.1 (#2780)
  * [ignore] bumps go deps (#2746)
  * [ignore] update dependabot go mod directories (#2740)
  * Bump github.com/prometheus/client_golang from 1.21.0 to 1.21.1
    (#2736)
  * [BUGFIX] Fix the interface impl of the datasource discovery
    (#2714)
  * [ignore] move datasource discovery test to the new plugin
    system (#2712)
  * [FEATURE] By configuration, disable datasource and variable
    (#2673)
  * [ignore] bumps go deps (#2707)
  * [IGNORE] fix goreleaser archive format field used (#2706)
  * [IGNORE] run all tests on windows (#2701)
  * Bump github.com/google/cel-go from 0.23.2 to 0.24.1 (#2703)
  * Bump github.com/PaesslerAG/gval from 1.2.2 to 1.2.4 (#2704)
  * [ENHANCEMENT] CLI/Migrate: support CR as a migration format
    (#2682)
  * Bump golang.org/x/crypto from 0.34.0 to 0.35.0 (#2681)
  * update go deps (#2679)
  * Bump github.com/labstack/echo-jwt/v4 from 4.2.0 to 4.3.0
    (#2479)
  * [BREAKINGCHANGE] Remove `percli plugin update` command (#2660)
  * Bump golangci/golangci-lint-action from 6.3.1 to 6.5.0 (#2650)
  * Bump github.com/huandu/go-sqlbuilder from 1.33.1 to 1.34.0
    (#2654)
  * Bump perses/github-actions from 0.8.0 to 0.9.0 (#2651)
  * Bump github.com/goreleaser/goreleaser/v2 from 2.6.1 to 2.7.0
    (#2655)
  * Bump the k8s-io group with 3 updates (#2652)
  * Bump github.com/spf13/cobra from 1.8.1 to 1.9.1 (#2653)
  * upgrade to node v22 (#2636)
  * Bump golang.org/x/mod from 0.22.0 to 0.23.0 (#2620)
  * Bump golang.org/x/crypto from 0.32.0 to 0.33.0 (#2621)
  * Bump golang.org/x/oauth2 from 0.25.0 to 0.26.0 (#2622)
  * Bump golangci/golangci-lint-action from 6.2.0 to 6.3.1 (#2623)
  * Bump cuelang.org/go from 0.11.2 to 0.12.0 (#2599)
  * bump github.com/perses/common to v0.27.0 to support TLS server
    (#2605)
  * Bump github.com/goreleaser/goreleaser/v2 from 2.5.1 to 2.6.1
    (#2592)
  * chore(deps): upgrade TanStack Query to version 5 [WIP] (#2588)
  * Bump cuelang.org/go from 0.11.1 to 0.11.2 (#2591)
  * bump turbo and module-federation version (#2590)
  * bump rspack to last version
  * Bump github.com/zitadel/oidc/v3 from 3.34.0 to 3.34.1 (#2572)
  * Bump github.com/prometheus/common from 0.61.0 to 0.62.0 (#2571)
  * Bump the k8s-io group with 3 updates (#2570)
  * Bump golangci/golangci-lint-action from 6.1.1 to 6.2.0 (#2573)
  * Bump github.com/goreleaser/goreleaser/v2 from 2.5.0 to 2.5.1
    (#2536)
  * Bump golang.org/x/crypto from 0.31.0 to 0.32.0 (#2550)
  * Bump github.com/labstack/echo/v4 from 4.13.2 to 4.13.3 (#2527)
  * Bump github.com/zitadel/oidc/v3 from 3.33.1 to 3.34.0 (#2537)
  * Bump golang.org/x/oauth2 from 0.24.0 to 0.25.0 (#2538)
  * Bump cuelang.org/go from 0.11.0 to 0.11.1 (#2528)
  * Bump perses/github-actions from 0.7.1 to 0.8.0 (#2529)
  * Bump github.com/mholt/archives (#2539)
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.3:
  * [ENHANCEMENT] allow insecureSkipVerify to be optional
    defaulting to false (#2803)
  * [ENHANCEMENT] Support min/max TLS version (#2619)
  * [ENHANCEMENT] Improve dashboard performance by reducing
    re-renders (#2770)
  * [ENHANCEMENT] make proxy authorization optional (#2802)
  * [ENHANCEMENT] Add OAuth secret type for Datasources (#2631)
  * [ENHANCEMENT] Update PanelEditorForm by using watched values
    (#2792)
  * [ENHANCEMENT] Add Authorization and BasicAuth definitions to
    cue package (#2643)
  * [BUGFIX] fix variable grafana migration (#2699)
  * [BUGFIX] Format expireAt with ISOString to fix
    EphemeralDashboard view crash (#2778)
  * [BUGFIX] Fix duplicate query keys in useQueries() (#2779)
  * [DOC] Fix doc about TLS config and the TLS secret spec (#2685)
  * [DOC] Fix typo in ListVariable spec (#2691)
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.2:
  * [FEATURE] add yaml and yaml custom resource to download formats
    (#2658)
  * [ENHANCEMENT] bump github.com/perses/common to v0.27.0 to
    support TLS server
  * [ENHANCEMENT] Allow npm install flags to be passed in make
    build-ui command (#2727)
  * [BUGFIX] Table: fix reorder columns button tooltip (#2722)
  * [BUGFIX] HTTPSettingsEditor: remove directUrl/proxy of previous
    value (#2739)
  * [BUGFIX] Fix the interface impl of the datasource discovery
    (#2714)
  * [BUGFIX] Refresh RBAC cache when adding or removing users.
    (#2670)
  * [BUGFIX] Dashboard copy: hide ephemeral option if disabled
    (#2633)
  * [BUGFIX] add id to avoid setState loops (#2600)
  * [BUGIFX] ListVariable: do not clear input value when selecting
    a value (#2672)
* Fri Jan 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.1:
  * Merge pull request #2584 from perses/nexucis/release
  * [IGNORE] CI: e2e: bump actions/upload-artifact to v4 (#2564)
  * [FEATURE] Label metrics in stat chart (#2574)
  * [BUGFIX] Inject API prefix in all UI assets (#2576)
  * [BUGFIX] Login from percli (method not allowed) (#2577)
  * [FEATURE] Value mapping settings for Status History and Stat
    Chart (#2462)
  * [IGNORE] Add error boundary around recent dashboard on home
    page (#2560)
  * [BUGFIX] ListVariable: fix autocomplete when 'All' is selected
    (#2554)
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.0:
  * Release v0.50.0 (#2553)
  * [BUGFIX] Update unit's migration (#2519)
  * [BUGFIX] GaugeChartPanel: fix empty state (#2548)
  * [BUGFIX] Fixes tooltip display in EDGE / IE (#2547)
  * [BUGFIX] Redirect to the desired page after login success
    (#2354)
  * [IGNORE] Correctly type useQuery fetch hooks error (#2546)
  * BUGFIX: `percli dac setup`: fix useless requirement of go CLI
    when using CUE (#2544)
  * Release v0.50.0-rc.1 (#2543)
  * [BUGFIX] DaC CUE SDK: Fix inconsistencies in mandatory vs
    optional attributes in dashboard lib (#2540)
  * [ENHANCEMENT] : percli plugin lint: improve the way to find the
    schema files (#2526)
  * [ENHANCEMENT] `percli dac diff`: add output + avoid early
    return when processing a directory (#2500)
  * [ENHANCEMENT] DaC CUE SDK: accurate constraints for duration
    attributes (#2525)
  * [ENHANCEMENT] DaC CUE SDK: add datasource param to the var
    group builder (#2524)
  * [BUGFIX] Fix preview display name with prefix (#2520)
  * [ENHANCEMENT] Use Perses logo for the app loader (#2518)
  * [BUGFIX] Fix for migration of decimal units (#2493)
  * [BUGFIX] Table panel: fix cell mapping for range condition
    (#2517)
  * [ENHANCEMENT] Table panel: editor text fields are debounced
    (#2470)
  * [DOC] Align plugin doc with the migration revamp (#2516)
  * Release v0.50.0-rc.0 (#2515)
  * [IGNORE] Upgrade to TypeScript 5.4 + upgrade eslint (#2513)
  * update go deps (#2512)
  * Bump the k8s-io group with 3 updates (#2508)
  * Downgrade TypeScript version to v5.3 + enforce return typing
    (#2504)
  * [IGNORE] Upgrade TypeScript to v5.4 (#2502)
  * [IGNORE] Enforce typing in eslint base config (#2499)
  * [IGNORE] Enforce typing for plugin-system package (#2494)
  * [IGNORE] Enforce typing for e2e package (#2498)
  * [IGNORE] Enforce typing for storybook package (#2497)
  * [IGNORE] Enforce typing for tempo-plugin package (#2496)
  * [IGNORE] Enforce typing for prometheus-plugin package (#2495)
  * [IGNORE] Enforce typing for panels-plugin package (#2491)
  * [IGNORE] Enforce typing for explore package (#2489)
  * [IGNORE] Enforce typing for internal-utils package (#2490)
  * [IGNORE] Enforce typing for dashboards package (#2488)
  * [ENHANCEMENT] Improve the migration (#2481)
  * Bump github.com/huandu/go-sqlbuilder from 1.32.0 to 1.33.1
    (#2477)
  * [IGNORE] Enforce typing for app package (#2487)
  * Bump github.com/labstack/echo/v4 from 4.12.0 to 4.13.0 (#2478)
  * Bump github.com/prometheus/common from 0.60.1 to 0.61.0 (#2476)
  * [DOC] Adjustments in CLI doc (#2480)
  * [IGNORE] Ignore more flaky links checks (#2486)
  * [IGNORE] Enforce typing for components package (#2485)
  * [BUGFIX] `dac diff`: fix output folder not found (#2484)
  * [ENHANCEMENT] Table: add default column sorting (#2482)
  * [IGNORE] Upgrade MUI to v6 (#2473)
  * [FEATURE] add plugin build command (#2471)
  * [ENHANCEMENT] Table panel: migrate custom column ordering via
    "organize" transformation (#2419)
  * [BUGFIX] Table: mapping with min range 0 not working (#2472)
  * [IGNORE] Replace some wrong usage of "chart" term by "panel"
    (#2468)
  * [IGNORE] CLI remove useless check for output flag (#2467)
  * [ENHANCEMENT] Add search in metric finder + new option for
    hiding panel (#2466)
  * [ENHANCEMENT] Add sparkline migration (#2463)
  * Bump perses/github-actions from 0.6.0 to 0.7.1 (#2434)
  * [ENHANCEMENT] CLI/DAC: return a success message after writing a
    diff files (#2464)
  * Update text migration (#2465)
  * Add yellow mapping from grafana (#2461)
  * [ENHANCEMENT] Table: add default column width setting (#2446)
  * [BUGFIX] Table: fix migration of joinByField transform (#2458)
  * [FEATURE] add plugin lint command (#2459)
  * [ENHANCEMENT] Prefix dashboard display name when using dac
    preview command (#2460)
  * [BUGFIX] Fix Panel JSON validation (#2456)
  * [ENHANCEMENT] Add piechart migration (#2449)
  * [ENHANCEMENT] Table: add column sorting (#2450)
  * [IGNORE] Add function type check on core package (#2447)
  * upgrade debian version in Dockerfiles (#2441)
  * [IGNORE] Upgrade react-table and react-virtuoso + remove some
    sx props leaks (#2445)
  * [ENHANCEMENT] Table: best-effort migration of
    fieldConfig.overrides to columnSettings (#2443)
  * [ENHANCEMENT] Add cell focus on hover (#2442)
  * [FEATURE] Status History panel (#2403)
  * [BUGFIX] Fix tree view broken when using prometheus built-in
    vars (#2405)
  * copy duration type from prometheus/common (#2440)
  * add @jgbernalp as maintainer of the perses org (#2438)
  * [ENHANCEMENT] Update kubebuilder validation (#2437)
  * Bump github.com/stretchr/testify from 1.9.0 to 1.10.0 (#2436)
  * Bump the k8s-io group with 3 updates (#2435)
  * [ENHANCEMENT] add kubebuilder annotations to all duration types
    (#2433)
  * [BUGFIX] TimeSeriesChart: fix migration for the format
    attribrute (#2432)
  * [ENHANCEMENT] RoleBinding prechecking if user and role exist
    has been removed (#2430)
  * [IGNORE] Add optional local prometheus and tempo to dev env
    (#2418)
  * [IGNORE] Bump CUE to latest release (#2423)
  * Bump github.com/zitadel/oidc/v3 from 3.32.1 to 3.33.1 (#2422)
  * [ENHANCEMENT] Refactor struct field names and add validation
    for duration fields (#2360)
  * [BUGFIX] PromQL Tree view: stop firing the parse query before
    the show button gets clicked (#2427)
  * Bump cuelang.org/go from 0.11.0-alpha.5 to 0.11.0-rc.1 (#2421)
  * [FEATURE] new CLI command for plugins development (#2410)
  * Bump golang.org/x/mod from 0.21.0 to 0.22.0 (#2411)
  * Bump golang.org/x/crypto from 0.28.0 to 0.29.0 (#2412)
  * Bump cuelang.org/go from 0.11.0-alpha.4 to 0.11.0-alpha.5
    (#2414)
  * [BUGFIX] Fix login command avoiding reusing previous config
    (#2416)
  * Bump github.com/huandu/go-sqlbuilder from 1.31.0 to 1.32.0
    (#2415)
  * Bump golang.org/x/oauth2 from 0.23.0 to 0.24.0 (#2413)
  * [FEATURE] Table panel: columns can be reordered (#2392)
  * [ENHANCEMENT] More user-friendly helpers for prometheus
    built-in variables (#2407)
  * [BUGFIX] Remove some SX props leaking (#2408)
  * [BUGFIX] Edit mode not working after clicking on the resource
    row (#2404)
  * Migrate defaultValue (#2406)
  * [IGNORE] small fix in DaC doc (#2402)
  * [IGNORE] Add some external variables to the dev data (#2088)
  * [IGNORE] fix remaining indentation issues for the doc website
    (#2400)
  * update contact list in github issue (#2398)
  * [DOC] Adjust markdown syntax following issues spotted on
    website (#2397)
- remove patch b04061023c941d879460d81e6e4c6019621dbc16.patch
* Tue Dec 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- backport patch b04061023c941d879460d81e6e4c6019621dbc16.patch to
  fix failing logins
  https://github.com/perses/perses/pull/2416
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.49.0:
  CLI-related changes:
  * [DOC] better wording for `percli dac`'s commands helpers
    (#2350)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.48.0:
  https://github.com/perses/perses/releases/tag/v0.48.0
  CLI-related changes:
  * [DOC] Add links in the CLI doc (#2276)
  * [ENHANCEMENT] Ignore Not Found errors in percli delete command
    (#2184)
* Tue Sep 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package perses-cli: CLI for the Perses observability
  visualisation project
